<?php
/**
Plugin Name: nrelate Most Popular
Plugin URI: http://www.nrelate.com
Description: Easily display the most popular content from your website. Click on <a href="admin.php?page=nrelate-popular">nrelate &rarr; Most Popular</a> to configure your settings.
Author: <a href="http://www.nrelate.com">nrelate</a> and <a href="http://www.slipfire.com">SlipFire LLC.</a>
Version: 0.49.3
Author URI: http://nrelate.com/


// Copyright (c) 2010 nrelate, All rights reserved.
//
// Released under the GPL license
// http://www.opensource.org/licenses/gpl-license.php
//
// This is a plugin for WordPress
// http://wordpress.org/
//
//
// **********************************************************************
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// **********************************************************************
**/

/**
 * Define Plugin constants
 */
define( 'NRELATE_POPULAR_PLUGIN_VERSION', '0.49.3' );
define( 'NRELATE_POPULAR_ADMIN_SETTINGS_PAGE', 'nrelate-popular' );
define( 'NRELATE_POPULAR_ADMIN_VERSION', '0.03.0' );

define( 'NRELATE_LATEST_ADMIN_VERSION', '0.03.0' );
define( 'NRELATE_CSS_URL', 'http://static.nrelate.com/common_wp/' . NRELATE_POPULAR_ADMIN_VERSION . '/' );
define( 'NRELATE_BLOG_ROOT', urlencode(str_replace(array('http://','https://'), '', get_bloginfo( 'url' ))));
define( 'NRELATE_JS_DEBUG', isset($_REQUEST['nrelate_debug']) ? true : false );

define( 'NRELATE_ADMIN_COMMON_FILE', plugin_basename( __FILE__ ) );
define( 'NRELATE_ADMIN_DIR_NAME', trim( dirname( NRELATE_ADMIN_COMMON_FILE ), '/' ) );
define( 'NRELATE_ADMIN_DIR', WP_PLUGIN_DIR . '/' . NRELATE_ADMIN_DIR_NAME.'/admin');
define( 'NRELATE_ADMIN_URL', WP_PLUGIN_URL . '/' . NRELATE_ADMIN_DIR_NAME.'/admin');

/**
 * Define Path constants
 */
// Generic: will be assigned to the last nrelate plugin that loads
define( 'NRELATE_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
define( 'NRELATE_PLUGIN_NAME', trim( dirname( NRELATE_PLUGIN_BASENAME ), '/' ) );
define( 'NRELATE_PLUGIN_DIR', WP_PLUGIN_DIR . '/' . NRELATE_PLUGIN_NAME );
	
// Plugin specific
define( 'NRELATE_POPULAR_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
define( 'NRELATE_POPULAR_PLUGIN_NAME', trim( dirname( NRELATE_POPULAR_PLUGIN_BASENAME ), '/' ) );
define( 'NRELATE_POPULAR_PLUGIN_DIR', WP_PLUGIN_DIR . '/' . NRELATE_POPULAR_PLUGIN_NAME );
define( 'NRELATE_POPULAR_PLUGIN_URL', WP_PLUGIN_URL . '/' . NRELATE_POPULAR_PLUGIN_NAME );
define( 'NRELATE_POPULAR_SETTINGS_DIR', NRELATE_POPULAR_PLUGIN_DIR . '/popular_settings' );
define( 'NRELATE_POPULAR_SETTINGS_URL', NRELATE_POPULAR_PLUGIN_URL . '/popular_settings' );
define( 'NRELATE_POPULAR_ADMIN_DIR', NRELATE_POPULAR_PLUGIN_DIR . '/admin' );
define( 'NRELATE_POPULAR_IMAGE_DIR', NRELATE_POPULAR_PLUGIN_URL . '/images' );

// Load WP_Http
if( !class_exists( 'WP_Http' ) )
	include_once( ABSPATH . WPINC. '/class-http.php' );
	
// Load Language
load_plugin_textdomain('nrelate-popular', false, NRELATE_POPULAR_PLUGIN_DIR . '/language');

/**
 * Get the product status of all nrelate products.
 *
 * @since 0.49.0
 */
if ( ! defined( 'NRELATE_PRODUCT_STATUS' ) ) { require_once ( NRELATE_POPULAR_ADMIN_DIR . '/product-status.php' ); }

/**
 * Load plugin styles if another nrelate plugin has not loaded it yet.
 *
 * @since 0.46.0
 */
if (!isset($nrelate_thumbnail_styles)) { require_once ( NRELATE_POPULAR_ADMIN_DIR . '/styles.php' ); }

/**
 * Check related version to make sure it is compatible with MP
 */
$related_settings = get_option('nrelate_related_options');
$related_version = $related_settings['related_version'];
if($related_version!='' &&version_compare("0.47.4", $related_version)>0){
	$plugin = NRELATE_POPULAR_PLUGIN_BASENAME;
	$warning = "<p><strong>".__('nrelate Warning(s):', 'nrelate')."</strong></p>";
	$message .= "<li>".sprintf(__('You\'re running Related Content plugin version %1$s. The Most Popular plugin requires Related Content version to be 0.47.4 or higher.<br/>Please upgrade to the latest release of Related Content plugin before installing the Most Popular plugin.', 'nrelate' ), $related_version ) . "</li>";
	$closing = "<p>".__('The nrelate Most Popular plugin has been deactivated.','nrelate')."<br/><br/><a href=\"/wp-admin\">".__('Click here to return to your WordPress dashboard.','nrelate')."</a></p>";
	deactivate_plugins($plugin);
	wp_die( $warning . "<ol>" . $message . "<ol>" . $closing );
	return;
}

/**
 * Initializes the plugin and it's features.
 *
 * @since 0.1
 */
if (is_admin()) {

		//load common admin files if not already loaded from another nrelate plugin
		if ( !defined('NRELATE_COMMON_LOADED') ) {require_once ( NRELATE_POPULAR_ADMIN_DIR . '/common.php' );}

		//load plugin status
		require_once ( NRELATE_POPULAR_SETTINGS_DIR . '/popular-plugin-status.php' );

		
		//load popular menu
		require_once ( NRELATE_POPULAR_SETTINGS_DIR . '/popular-menu.php' );
}


/** Load common frontend functions **/
if ( ! defined( 'NRELATE_COMMON_FRONTEND_LOADED' ) ) { require_once ( NRELATE_POPULAR_ADMIN_DIR . '/common-frontend.php' );}

/** Load popular frontend js file **/
if (!is_admin()) {
	wp_register_script( 'nrelate_mp_js', NRELATE_POPULAR_SETTINGS_URL . '/popular_frontend'. ( NRELATE_JS_DEBUG ? '' : '.min') .'.js', array(), null, false);
	wp_enqueue_script('nrelate_mp_js');
}

/*
 * Load popular styles
 *
 * since v.44.0
 * updated v46.0
 */
function nrelate_popular_styles() {
	if (nrelate_popular_is_loading()) {
		$options = get_option('nrelate_popular_options');
		$style_options = get_option('nrelate_popular_options_styles');
		if ($options['popular_thumbnail']=='Thumbnails') {
			//Thumbnails mode
			if ('none'==$style_options['popular_thumbnails_style']) return;
			$style_type = $style_options['popular_thumbnails_style'];
			$stylesheet = 'nrelate-panels-' . $style_type .'.min.css';
			
			// Register ie6 styles
			$nr_css_ie6_url = NRELATE_CSS_URL . "ie6-panels.min.css";
			$nr_ie6_id = 'nrelate-ie6-' . str_replace(".","-",NRELATE_POPULAR_ADMIN_VERSION);
			wp_register_style($nr_ie6_id, $nr_css_ie6_url, false, null );
			$GLOBALS['wp_styles']->add_data( $nr_ie6_id, 'conditional', 'IE 6' );
		
		} else {
		//Text mode
			if ('none'==$style_options['popular_text_style']) return;
			$style_type = 'text' . $style_options['related_text_style'];
			$stylesheet = 'nrelate-text-'.$style_options['popular_text_style'].'.min.css';
		}
		
		$nr_css_url = NRELATE_CSS_URL . $stylesheet;
		
		// For local development
		//$nr_css_url = NRELATE_POPULAR_PLUGIN_URL . '/' . $stylesheet;
		
		
		wp_register_style('nrelate-style-'. $style_type . "-" . str_replace(".","-",NRELATE_POPULAR_ADMIN_VERSION), $nr_css_url, false, null );
		wp_enqueue_style( 'nrelate-style-'. $style_type . "-" . str_replace(".","-",NRELATE_POPULAR_ADMIN_VERSION) );
		wp_enqueue_style( 'nrelate-ie6-' . str_replace(".","-",NRELATE_POPULAR_ADMIN_VERSION) );
	}
}
add_action('wp_print_styles', 'nrelate_popular_styles');

/*
 * Check if nrelate is loading (frontend only)
 *
 * 
 */
function nrelate_popular_is_loading() {
	$is_loading = false;
   
    if ( !is_admin() ) {   
        $options = get_option('nrelate_popular_options');
       
        if ( isset($options['popular_where_to_show']) ) {
            foreach ( (array)$options['popular_where_to_show'] as $cond_tag ) {
                if ( function_exists( $cond_tag ) && call_user_func( $cond_tag ) ) {
                    $is_loading = true;
                    break;
                }
            }
        }
    }
   
    return apply_filters( 'nrelate_popular_is_loading', $is_loading);
}

/**
 * Inject popular posts into the content
 *
 * Stops injection into themes that use get_the_excerpt in their meta description
 *
 * @since 0.1
 */
function nrelate_popular_inject($content) {

	global $post;
	
	if ( nrelate_popular_should_inject() ) {

		$nrelate_popular_options = get_option( 'nrelate_popular_options' );

		$popular_loc_top = $nrelate_popular_options['popular_loc_top'];
		$popular_loc_bottom = $nrelate_popular_options['popular_loc_bottom'];
		$popular_where = $nrelate_popular_options['popular_where_to_show'];

		if ($popular_loc_top == "on"){
			$content_top = nrelate_popular(true);
		} else {
			$content_top = '';
		};

		if ($popular_loc_bottom == "on"){
			$content_bottom = nrelate_popular(true);
		} else {
			$content_bottom = '';
		};
		$increment_str='';
		if(is_single() && !nrelate_popular_is_loading())
			$increment_str=nrelate_popular_counter();
		
		$original = $content;

		$content  = $content_top;
		$content .= $original;
		$content .= $content_bottom;
		$content .= $increment_str;

	}
	return $content;
}
add_filter( 'the_content', 'nrelate_popular_inject', 10 );
add_filter( 'the_excerpt', 'nrelate_popular_inject', 10 );

// Added 06/09/11 YK: if nrelate_popular is not shown and is single page, increment counter
function nrelate_popular_counter(){
	$post_link = get_permalink($post->ID);
	$post_urlencoded = urlencode($post_link);
	$nr_mp_url="http://api.nrelate.com/mpw_wp/".NRELATE_POPULAR_PLUGIN_VERSION."/loadcounter.php?tag=nrelate_popular";
	$nr_mp_url.="&domain=".NRELATE_BLOG_ROOT."&url=".$post_urlencoded;
	$increment_str.=<<<EOD
<script type="text/javascript">
//<![CDATA[ 
if(nRelate.increment==0){
	nRelate.increment=1;
	var nr_mp_prev_url=nr_mp_get_url_cookie();
	var nr_mp_current_url=escape("$post_link");
	if(nr_mp_prev_url==nr_mp_current_url){
		nRelate.increment=0;
	}
	nr_mp_set_url_cookie(nr_mp_current_url);	
	if(nRelate.increment==1){
		jQuery.getScript("$nr_mp_url");
	}
}
//]]>
</script>
EOD;
	return $increment_str;
}

/**
 * Returns true if currently the_content or the_excerpt
 * filter should be injected with nrelate code
 *
 * 
 */
function nrelate_popular_should_inject() {
	global $wp_current_filter;
	
	$should_inject = true;
	
	if ( !nrelate_is_main_loop() ) {
		// Don't inject if out of main loop
		$should_inject = false;
	} elseif ( in_array( 'get_the_excerpt', $wp_current_filter ) ) {
		// Don't inject if calling get_the_excerpt
		$should_inject = false;
	} elseif ( is_single() && in_array( 'the_excerpt', $wp_current_filter ) ) {
		// Don't inject the_excerpt on single post pages
		$should_inject = false;
	}
	
	// Third party widgets
	// For php 5.25 support: debug_backtrace(false);
	$call_stack = debug_backtrace();
	foreach ( $call_stack as $call ) {
		if ( $call['function'] == 'widget' ) {
			$should_inject = false;
			break;
		}
	}
	
	return apply_filters( 'nrelate_popular_should_inject', $should_inject );
}

/**
 * nrelate popular shortcode
 *
 * @since 0.1
 */
function nrelate_popular_shortcode ($atts) {
	extract(shortcode_atts(array(
		"float" => 'left',
		"width" => '100%',
	), $atts));

    return '<div class="nr-mp-shortcode" style="float:'.$float.';width:'.$width.';\">'.nrelate_popular(true).'</div>';
}
add_shortcode('nrelate-popular', 'nrelate_popular_shortcode');

/**
 * Register the widget.
 *
 * @uses register_widget() Registers individual widgets.
 * @link http://codex.wordpress.org/WordPress_Widgets_Api
 *
 * @written in 0.1
 * @live in 0.41.0
 */
function nrelate_popular_load_widget() {

	//Load widget file.
	require_once( 'popular-widget.php' );

	// Register widget.
	register_widget( 'nrelate_Widget_Popular' );
};
add_action( 'widgets_init', 'nrelate_popular_load_widget' );



/**
 * Primary function
 *
 * Gets options and passes to nrelate via Javascript
 * 
 * @since 0.1
 */

$nr_mp_counter=0;
function nrelate_popular($opt=false) {
	global $nr_mp_counter,$post;
	$animation_fix = $nr_mp_nonjsbody = $nr_mp_nonjsfix = $nr_mp_js_str = '';
	if (nrelate_popular_is_loading())  {
		$nr_mp_counter++;
		$nrelate_popular_options = get_option( 'nrelate_popular_options' );
		$p_max_age = $nrelate_popular_options['popular_max_age_num'];
		$p_max_frame = $nrelate_popular_options['popular_max_age_frame'];
		switch ($p_max_frame){
		case 'Hour(s)':
		  $maxageposts = $p_max_age * 60;
		  break;
		case 'Day(s)':
		  $maxageposts = $p_max_age * 1440;
		  break;
		case 'Week(s)':
		  $maxageposts = $p_max_age * 10080;
		  break;
		case 'Month(s)':
		  $maxageposts = $p_max_age * 44640;
		  break;
		case 'Year(s)':
		  $maxageposts = $p_max_age * 525600;
		  break;
		}
		$nr_mp_counter+=1;
		// Assign options
		$mp_style_options = get_option('nrelate_popular_options_styles');
		$mp_style_code = 'nrelate_' . (($nrelate_popular_options['popular_thumbnail']=='Thumbnails') ? $mp_style_options['popular_thumbnails_style'] : $mp_style_options['popular_text_style']);
		$nr_mp_width_class = 'nr_' . (($nrelate_popular_options['popular_thumbnail']=='Thumbnails') ? $nrelate_popular_options['popular_thumbnail_size'] : "text");
		$post_link = get_permalink($post->ID);
		$post_urlencoded = urlencode($post_link);
		
		$nonjs=$nrelate_popular_options['popular_nonjs'];
		
		$nr_url = "http://api.nrelate.com/mpw_wp/" . NRELATE_POPULAR_PLUGIN_VERSION . "/?tag=nrelate_popular";
		$nr_url .= "&domain=" . NRELATE_BLOG_ROOT . "&url=$post_urlencoded&nr_div_number=".$nr_mp_counter."&maxageposts=".$maxageposts;
		$nr_url .= is_home() ? '&source=hp' : '';
		$increment=0;
		//is loaded only once per page for popular
		if (!defined('NRELATE_POPULAR_HOME')) {
			define('NRELATE_POPULAR_HOME', true);
			// Added to create disjoint between keeping count and displaying
			// If this page is single, $increment=1
			// If this page is single, send increment as 1. Call this only once
		
			if(is_single())
				$increment=1;
		
			$animation_fix = '<style type="text/css">.nrelate .nr_sponsored{ left:0px !important; }</style>';
			if (!empty($nrelate_popular_options['popular_ad_animation'])) {
				$animation_fix = '';
			}
		}
		//is loaded only once per page for nrelate
		if (!defined('NRELATE_HOME')) {
			define('NRELATE_HOME', true);
			$domain = addslashes(NRELATE_BLOG_ROOT);
			$script= <<< EOD
					$animation_fix
					<script type="text/javascript">
					//<![CDATA[
					nRelate.domain = "{$domain}";
					//]]>
					</script>
EOD;
			echo $script;
		}
		
		if($nonjs){
			$request = new WP_Http;
		    $args=array("timeout"=>5);
		    $increment_str="";
		    if($increment==1)
		    	$increment_str="&increment=1";
		    $response = $request->request( $nr_url.$increment_str."&nonjs=1",$args);
		    if( !is_wp_error( $response ) ){
			    if($response['response']['code']==200 && $response['response']['message']=='OK'){
				    $nr_mp_nonjsbody=$response['body'];
			   		$nr_mp_nonjsfix='<script type="text/javascript">nRelate.fixHeight("nrelate_popular_'.$nr_mp_counter.'");';
			   		$nr_mp_nonjsfix.='nRelate.adAnimation("nrelate_popular_'.$nr_mp_counter.'");';
					$nr_mp_nonjsfix.='nRelate.tracking("mp");</script>';
			    }else{
			    	$nr_mp_nonjsbody="<!-- nrelate server not 200. -->";
			    }
		    }else{
		    	$nr_mp_nonjsbody="<!-- WP-request to nrelate server failed. -->";
		    }
		}
		else{
			$nr_mp_js_str= <<<EOD
<script type="text/javascript">
	//<![CDATA[
		nRelate.increment=$increment;
		var nr_mp_prev_url=nr_mp_get_url_cookie();
		var nr_mp_current_url=escape("$post_link");
		if(nr_mp_prev_url==nr_mp_current_url){
			nRelate.increment=0;
		}
		var nr_mpw_inc_str='';
		if(nRelate.increment==1)
			nr_mpw_inc_str='&increment=1';
		var entity_decoded_nr_mp_url = jQuery('<span/>').html("$nr_url"+nr_mpw_inc_str).text();
		nRelate.getNrelatePosts(entity_decoded_nr_mp_url);
		nr_mp_set_url_cookie(nr_mp_current_url,nRelate.domain);
	//]]>
	</script>
EOD;
		}
		$markup = <<<EOD
$animation_fix
<div class="nr_clear"></div>	
	<div id="nrelate_popular_{$nr_mp_counter}" class="nrelate nrelate_popular $mp_style_code $nr_mp_width_class">$nr_mp_nonjsbody</div>
	<!--[if IE 6]>
		<script type="text/javascript">jQuery('.$mp_style_code').removeClass('$mp_style_code');</script>
	<![endif]-->
	$nr_mp_nonjsfix
	$nr_mp_js_str
<div class="nr_clear"></div>
EOD;

		if ($opt){
			return $markup;
		}else{
			echo $markup;
		}
	}
};


//Activation and Deactivation functions
//Since 0.47.4, added uninstall hook again
register_activation_hook(__FILE__, 'nr_mp_add_defaults');
register_deactivation_hook(__FILE__, 'nr_mp_deactivate');
register_uninstall_hook(__FILE__, 'nr_mp_uninstall');
?>
